@@ -114,7 +114,8 @@ $mirrors = {
       'http://mirrors.fe.up.pt/pub/CTAN/' => 1
     },
     'Russia' => {
-      'http://ctan.altspu.ru/' => 1
+      'http://ctan.altspu.ru/' => 1,
+      'http://mirror.macomnet.net/pub/CTAN/' => 1
     },
     'Serbia' => {
       'http://ctan.mirror.ftn.uns.ac.rs/' => 1
@@ -140,7 +141,8 @@ $mirrors = {
     'Canada' => {
       'http://ctan.math.ca/tex-archive/' => 1,
       'http://ctan.mirror.rafal.ca/' => 1,
-      'http://mirror.its.dal.ca/ctan/' => 1
+      'http://mirror.its.dal.ca/ctan/' => 1,
+      'http://muug.ca/mirror/ctan/' => 1
     },
     'Costa Rica' => {
       'http://mirrors.ucr.ac.cr/CTAN/' => 1
